@@ -1,5 +1,6 @@
-from typing import Any, Iterable, Optional, overload
+from typing import Any, Iterable, overload
 
+from .null_text import NullText
 from .text import Text
 from .text_corpus import TextCorpus
 
@@ -21,11 +22,14 @@ class DictionaryTextCorpus(TextCorpus):
     def texts(self) -> Iterable[Text]:
         return sorted(self._texts.values(), key=lambda t: t.sort_key)
 
-    def get_text(self, id: str) -> Optional[Text]:
-        return self._texts.get(id)
+    def __getitem__(self, id: str) -> Text:
+        text = self._texts.get(id)
+        if text is None:
+            text = self.create_null_text(id)
+        return text
 
-    def get_text_sort_key(self, id: str) -> str:
-        return id
+    def create_null_text(self, id: str) -> Text:
+        return NullText(id, id)
 
     def _add_text(self, text: Text) -> None:
         self._texts[text.id] = text
