@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import Iterable, Optional
+from typing import Iterable
 
 from .text_alignment_collection import TextAlignmentCollection
 
@@ -11,13 +11,16 @@ class TextAlignmentCorpus(ABC):
         ...
 
     @abstractmethod
-    def get_text_alignment_collection(self, id: str) -> Optional[TextAlignmentCollection]:
+    def __getitem__(self, id: str) -> TextAlignmentCollection:
+        ...
+
+    @abstractmethod
+    def create_null_text_alignment_collection(self, id: str) -> TextAlignmentCollection:
         ...
 
     @abstractmethod
     def invert(self) -> "TextAlignmentCorpus":
         ...
 
-    @abstractmethod
-    def get_text_alignment_collection_sort_key(self, id: str) -> str:
-        ...
+    def get_text_alignment_collection(self, id: str) -> TextAlignmentCollection:
+        return self[id]
